Conversation

Enum Conversation 

pub enum Conversation {
Show 13 variants Advice, Details, Dreams, Event, Fourth, Greeting, Hint, Jokes, Problems, Quest, Quotes, SmallTalk, Surroundings,
}

Variants



Advice

General life advice, such as proverbs



Details

Describing anything in great detail



Dreams

Talks about their own dreams



Event

Talking about an in-gmae event



Fourth

Breaking the fourth wall, being self aware



Greeting

A simple “Hello”, “Good day”, “How are you?”



Hint

General gameplay tips



Jokes

Random puns



Problems

Talks about personal problems



Quest

In game hints to drive the story/quest



Quotes

Random public domain material



SmallTalk

Any number of random things about the weather, sports, etc.



Surroundings

Talks about geological/biological features of the surroundings